# eventsflow

[![Build Status](https://travis-ci.org/eventsflow/eventsflow.svg?branch=master)](https://travis-ci.org/eventsflow/eventsflow)

Simple library and console tool for building data processing pipelines, https://eventsflow.github.io/eventsflow/

## Development

For local testing please be sure that [drone-cli](https://github.com/drone/drone-cli) installed

